@@ -3,10 +3,6 @@ import matplotlib.pyplot as plt
 import numpy as np
 import os.path
 
-def str_to_list(myStr):
-    return [o.strip() for o in myStr.split(",")]
-
-
 def tabulate_reports(remote_calls, homecall_reports):
     # flatten nested dict
     records = []
@@ -31,8 +27,6 @@ def build_connectivity_info(decodes, start_epoch = 0, bands = "20m", modes = "FT
     """
     remote_calls = {}
     homecall_reports = {}
-    bands = str_to_list(bands)
-    modes = str_to_list(modes)
 
     for d in decodes:
         if(int(d['t']) < start_epoch or d['b'] not in bands or d['md'] not in modes):
