@@ -8,14 +8,19 @@ import os
 import datetime
 import subprocess
 
+global myBands, myModes, mySquares
+
 def get_cfg():
+    global myBands, myModes, mySquares
     with open("hamplots.cfg","r") as f:
         lines = f.readlines()
-    squares = lines[0]
-    bands = lines[1]
-    modes = lines[2]
-    return bands, modes, squares
-        
+    mySquares = [e.strip() for e in lines[0].split(",")]
+    myBands = [e.strip() for e in lines[1].split(",")]
+    myModes = [e.strip() for e in lines[2].split(",")]
+    print(f"mySquares {mySquares}")
+    print(f"myBands {myBands}")
+    print(f"myModes {myModes}")
+
 
 def my_pcolor(ax, fig, rowheads, colheads, cells):
     nx=len(colheads)
@@ -30,7 +35,6 @@ def my_pcolor(ax, fig, rowheads, colheads, cells):
     ax.tick_params(top=True, bottom=False, labeltop=True, labelbottom=False)
     
 def start_rx(runsecs):
-    bands, modes, squares = get_cfg()
     print("Start Rx")
     rx_listener = hp.pskr_listener(mySquares, modes = myModes, bands = myBands, TxRx = "Rx", to_file = "Rx_decodes.csv")
     rx_listener.loop_for_time(runsecs);
@@ -38,13 +42,30 @@ def start_rx(runsecs):
     rx_listener.disconnect();
 
 def start_tx(runsecs):
-    bands, modes, squares = get_cfg()
     print("Start Tx")
     tx_listener = hp.pskr_listener(mySquares, modes = myModes, bands = myBands, TxRx = "Tx", to_file = "Tx_decodes.csv")
     tx_listener.loop_for_time(runsecs);
     print("Disconnect Tx")
     tx_listener.disconnect();
 
+def start_all(refreshsecs, plotwinsecs):
+    print("Starting Rx listener")
+    subprocess.Popen(["hamplots", "start_rx", "--runsecs", "1000000"], creationflags=subprocess.CREATE_NO_WINDOW)
+    print("Starting Tx listener")
+    subprocess.Popen(["hamplots", "start_tx", "--runsecs", "1000000"], creationflags=subprocess.CREATE_NO_WINDOW)
+    print(f"Starting Uploader with period {refreshsecs} secs and plot window {plotwinsecs} secs")
+    while (True):
+        time.sleep(refreshsecs)
+        repo_dir = r"C:\Users\drala\Documents\Projects\GitHub\hamplots"
+        subprocess.run(["hamplots", "do_plots", "--plotwinsecs", str(plotwinsecs)], cwd = repo_dir)
+        subprocess.run(["git", "add", "-f", "./plots/*.png"], cwd=repo_dir)
+        subprocess.run(["git", "add", "-f", "./plots/timestamp"], cwd=repo_dir)
+        subprocess.run(["git", "commit", "-m", "upload local data"], cwd=repo_dir)
+        subprocess.run(["git", "pull"], cwd=repo_dir)
+        subprocess.run(["git", "clean", "-f"], cwd=repo_dir)
+        subprocess.run(["git", "push", "-f"], cwd=repo_dir)
+        subprocess.run(["git", "reset"], cwd=repo_dir)
+
 def timestamp_plots():
     t = int(time.time())
     with open("plots/timestamp","w") as f:
@@ -68,15 +89,14 @@ def check_plots_are_old(refresh_secs):
 def do_plots(timewin_start_offset_secs):
     print(f"Starting plots with time window {timewin_start_offset_secs} secs")
 
-    bands, modes, squares = get_cfg()
     for RxTx in ["Rx","Tx"]:
         decodes = hp.read_csv(f"{RxTx}_decodes.csv")
         if(not decodes):
             continue
 
         timewin_start = time.time() - timewin_start_offset_secs
-        for band in myBands.split(", "):
-            for mode in myModes.split(", "):
+        for band in myBands:
+            for mode in myModes:
                 print(f"Rx_{band}_{mode}")
 
                 remote_calls, homecall_reports = hp.build_connectivity_info(decodes, start_epoch = timewin_start, bands=band, modes=mode)
@@ -133,6 +153,7 @@ def get_args_and_run():
     parser.add_argument('--refreshsecs', type=str, default = "600", help = "Upload to github every refreshsecs seconds")
  
     args = parser.parse_args()
+    get_cfg()
 
     print(f"args.action = .{args.action}.")
     if(args.action == "start_rx"):
@@ -153,25 +174,7 @@ def get_args_and_run():
         do_periodic_uploads(int(args.refreshsecs))
 
     if(args.action == "start_all"):
-        print("Starting Rx listener")
-        subprocess.Popen(["hamplots", "start_rx", "--runsecs", "1000000"], creationflags=subprocess.CREATE_NO_WINDOW)
-        print("Starting Tx listener")
-        subprocess.Popen(["hamplots", "start_tx", "--runsecs", "1000000"], creationflags=subprocess.CREATE_NO_WINDOW)
-        refreshsecs = int(args.refreshsecs)
-        plotwinsecs = int(args.plotwinsecs)
-        print(f"Starting Uploader with period {refreshsecs} secs and plot window {plotwinsecs} secs")
-        while (True):
-            time.sleep(refreshsecs)
-            repo_dir = r"C:\Users\drala\Documents\Projects\GitHub\hamplots"
-            subprocess.run(["hamplots", "do_plots", "--plotwinsecs", str(plotwinsecs)], cwd = repo_dir)
-            subprocess.run(["git", "add", "-f", "./plots/*.png"], cwd=repo_dir)
-            subprocess.run(["git", "add", "-f", "./plots/timestamp"], cwd=repo_dir)
-            subprocess.run(["git", "commit", "-m", "upload local data"], cwd=repo_dir)
-            subprocess.run(["git", "pull"], cwd=repo_dir)
-            subprocess.run(["git", "clean", "-f"], cwd=repo_dir)
-            subprocess.run(["git", "push", "-f"], cwd=repo_dir)
-            subprocess.run(["git", "reset"], cwd=repo_dir)
-
+        start_all(int(args.refreshsecs), int(args.plotwinsecs))
 
 
 
